@@ -16,19 +16,24 @@ class DealModel(Base):
     __tablename__ = "deals"
 
     id = Column(Integer, primary_key=True)
-    announcement_date = Column(DateTime, nullable=False)
+    announcement_date = Column(DateTime, nullable=False, index=True)
     round = Column(String(50), nullable=True)
     deal_value = Column(DECIMAL(13, 2), nullable=False)
     currency = Column(String(10), nullable=True)
     company_sec_id = Column(
         Integer,
         ForeignKey('companies_sec.id'),
-        nullable=False,
+        nullable=True,
     )
     company_ous_id = Column(
         Integer,
         ForeignKey('companies_ous.id'),
-        nullable=False,
+        nullable=True,
+    )
+    news_id = Column(
+        Integer,
+        ForeignKey('newswires.id'),
+        nullable=True,
     )
     updated_at = Column(
         DateTime,
