@@ -4,6 +4,7 @@ from sqlalchemy import (
     DateTime,
     Boolean,
     String,
+    Text,
 )
 from datetime import datetime
 
@@ -23,6 +24,10 @@ class InsightsQueueModel(Base):
         Boolean,
         nullable=True,
     )
+    error = Column(Text, nullable=True)
+    submitted = Column(Boolean, nullable=True)
+    submitted_date = Column(DateTime, nullable=True)
+    historical = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
