@@ -1,6 +1,6 @@
 from sqlalchemy.exc import SQLAlchemyError
 from datetime import datetime
-from marshmallow import ValidationError
+from marshmallow import ValidationError, EXCLUDE
 
 from ...database import db_session
 from ...utils.utils import update_model
@@ -58,12 +58,11 @@ class OrangeBookProduct:
             ValidationError
         """
 
-        data, errors = schema_params.load(params)
-        if errors:
-            raise ValidationError(errors)
+        data = schema_params.load(params, unknown=EXCLUDE)
+
         orange_book_product_query = _build_query(params=data)
         response = schema_resource.dump(
-            orange_book_product_query, many=True).data
+            orange_book_product_query, many=True)
         return response
 
     @staticmethod
@@ -77,11 +76,10 @@ class OrangeBookProduct:
             ValidationError
         """
 
-        data, errors = schema_params.load(params)
-        if errors:
-            raise ValidationError(errors)
+        data = schema_params.load(params, unknown=EXCLUDE)
+
         orange_book_product_query = _build_query(params=data).one()
-        response = schema_resource.dump(orange_book_product_query).data
+        response = schema_resource.dump(orange_book_product_query)
         return response
 
     @staticmethod
@@ -123,7 +121,7 @@ def _helper_create(data):
             OrangeBookProductModel).get(
             new_orange_book_product.id,
         )
-        response = schema_resource.dump(orange_book_product_query).data
+        response = schema_resource.dump(orange_book_product_query)
         db_session.close()
         return response
     except SQLAlchemyError:
@@ -138,7 +136,7 @@ def _helper_update(data, orange_book_product_query):
     try:
         update_model(data, orange_book_product_query)
         db_session.commit()
-        response = schema_resource.dump(orange_book_product_query).data
+        response = schema_resource.dump(orange_book_product_query)
         return response
     except SQLAlchemyError:
         db_session.rollback()
