@@ -31,7 +31,7 @@ class OrangeBookProductResourceSchema(Schema):
     drug_set_id = fields.String(allow_none=True)
 
     @pre_load
-    def load_date_fields(self, in_data):
+    def load_date_fields(self, in_data, **kwargs):
         date_fields = ['approval_date']
         in_data = pre_load_date_fields(
             in_data,
@@ -73,7 +73,7 @@ class OrangeBookProductPatchSchema(Schema):
     drug_set_id = fields.String(allow_none=True)
 
     @pre_load
-    def load_date_fields(self, in_data):
+    def load_date_fields(self, in_data, **kwargs):
         date_fields = ['approval_date']
         in_data = pre_load_date_fields(
             in_data,
